summaryrefslogtreecommitdiffstats
path: root/tdecore/kiconloader_p.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:16:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:16:51 -0600
commitf2bfcad7ffdd09911f282afe2a2051b3708601c9 (patch)
treece4bebc206b6f9753745218e6a4c4368df624c16 /tdecore/kiconloader_p.h
parenta14eaa044240517f1f3d7eb5dacbff96fd447ada (diff)
downloadtdelibs-f2bfcad7ffdd09911f282afe2a2051b3708601c9.tar.gz
tdelibs-f2bfcad7ffdd09911f282afe2a2051b3708601c9.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'tdecore/kiconloader_p.h')
-rw-r--r--tdecore/kiconloader_p.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/tdecore/kiconloader_p.h b/tdecore/kiconloader_p.h
index 4c3c87339..82ff9dbe8 100644
--- a/tdecore/kiconloader_p.h
+++ b/tdecore/kiconloader_p.h
@@ -9,8 +9,8 @@
* exact licensing terms.
*/
-#ifndef __KIconLoader_p_h_Included__
-#define __KIconLoader_p_h_Included__
+#ifndef __TDEIconLoader_p_h_Included__
+#define __TDEIconLoader_p_h_Included__
#include <tqobject.h>
#include <tqstringlist.h>
@@ -19,37 +19,37 @@
#include <kiconeffect.h>
#include <tqdict.h>
-class KIconThemeNode
+class TDEIconThemeNode
{
public:
- KIconThemeNode(KIconTheme *_theme);
- ~KIconThemeNode();
+ TDEIconThemeNode(TDEIconTheme *_theme);
+ ~TDEIconThemeNode();
- void queryIcons(TQStringList *lst, int size, KIcon::Context context) const;
- void queryIconsByContext(TQStringList *lst, int size, KIcon::Context context) const;
- KIcon findIcon(const TQString& name, int size, KIcon::MatchType match) const;
+ void queryIcons(TQStringList *lst, int size, TDEIcon::Context context) const;
+ void queryIconsByContext(TQStringList *lst, int size, TDEIcon::Context context) const;
+ TDEIcon findIcon(const TQString& name, int size, TDEIcon::MatchType match) const;
void printTree(TQString& dbgString) const;
- KIconTheme *theme;
+ TDEIconTheme *theme;
};
-class KIconLoaderPrivate : public TQObject
+class TDEIconLoaderPrivate : public TQObject
{
Q_OBJECT
public:
TQStringList mThemesInTree;
- KIconGroup *mpGroups;
- KIconThemeNode *mpThemeRoot;
+ TDEIconGroup *mpGroups;
+ TDEIconThemeNode *mpThemeRoot;
TDEStandardDirs *mpDirs;
- KIconLoader *q;
- KIconEffect mpEffect;
+ TDEIconLoader *q;
+ TDEIconEffect mpEffect;
TQDict<TQImage> imgDict;
TQImage lastImage; // last loaded image without effect applied
TQString lastImageKey; // key for icon without effect
TQString appname;
- int lastIconType; // see KIcon::type
- int lastIconThreshold; // see KIcon::threshold
- TQPtrList<KIconThemeNode> links;
+ int lastIconType; // see TDEIcon::type
+ int lastIconThreshold; // see TDEIcon::threshold
+ TQPtrList<TDEIconThemeNode> links;
bool extraDesktopIconsLoaded;
bool delayedLoading;
@@ -57,4 +57,4 @@ public slots:
void reconfigure();
};
-#endif // __KIconLoader_p_h_Included__
+#endif // __TDEIconLoader_p_h_Included__